@@ -29,12 +29,36 @@ setMethod("plot", c("DVH", "missing"),
 	}
 )
 
+setMethod("plot", c("zDVH", "missing"),
+	function(x, ...) {
+		plot.zDVH(x, ...)
+	}
+)
+
 setMethod("plot", c("DVH", "DVH"),
 	function(x, y, ...) {
 		plot.DVH(new("DVH.list",list(x)), new("DVH.list",list(y)), ...)
 	}
 )
 
+setMethod("plot", c("zDVH", "DVH"),
+	function(x, y, ...) {
+		plot.DVH(new("DVH.list",list(x)), new("DVH.list",list(y)), ...)
+	}
+)
+
+setMethod("plot", c("DVH", "zDVH"),
+	function(x, y, ...) {
+		plot.DVH(new("DVH.list",list(x)), new("DVH.list",list(y)), ...)
+	}
+)
+
+setMethod("plot", c("zDVH", "zDVH"),
+	function(x, y, ...) {
+		plot.DVH(new("DVH.list",list(x)), new("DVH.list",list(y)), ...)
+	}
+)
+
 
 setMethod("plot", c("DVH", "ANY"),
 	function(x, y, ...) {
@@ -42,6 +66,12 @@ setMethod("plot", c("DVH", "ANY"),
 	}
 )
 
+setMethod("plot", c("zDVH", "ANY"),
+	function(x, y, ...) {
+		plot.DVH(new("DVH.list",list(x)), y, ...)
+	}
+)
+
 setMethod("plot", c("DVH.list", "missing"),
 	function (x, y=NULL, ...) {
 		plot.DVH(x, ...)
@@ -462,3 +492,18 @@ plot.DVH.groups <- function(x, ..., col="black", lty ="solid", lwd=1, line.trans
 		legend(legend, legend=if (length(legend.labels) >= N) {legend.labels[1:N]} else {paste("Group", 1:N)}, lty=lty, lwd=lwd, col=col)
 	}
 }
+
+
+plot.zDVH <- function(x, ..., col="black", front=NULL, back=front, new=TRUE, dose=NULL, dose.units=NULL, volume=NULL, type=NULL, main="") {
+	dose.units <- match.arg(dose.units, choices=c(NA, "cGy", "Gy"))
+	type <- match.arg(type, choices=c(NA, "cumulative", "differential"))
+	volume <- match.arg(volume, choices=c(NA, "relative", "absolute"))
+	dose <- match.arg(dose, choices=c(NA, "absolute", "relative"))
+	front <- match.arg(front, choices=c("filled", "lines", "points", "culled"))
+	back <- match.arg(back, choices=c("filled", "lines", "points", "culled"))
+	x <- convert.DVH(x, type=type, dose=dose, dose.units=dose.units, volume=volume)
+	if (length(unique(diff(x$doses))) > 1) {
+		persp3d(x$doses[2:length(x$doses)], as.numeric(colnames(x$volumes)), x$volumes[2:length(x$doses),], col=col, border=NA, shade=0.5, xlab=paste("Dose (", x$dose.units, ")", sep=""), ylab="z (mm)", zlab=paste("Volume (", if (x$volume.type == "relative") {"%"} else {"cc"}, ")", sep=""), add=!new)
+	}
+	persp3d(x$doses, as.numeric(colnames(x$volumes)), x$volumes, col=col, border=NA, shade=0.5, xlab=paste("Dose (", x$dose.units, ")", sep=""), ylab="z (mm)", zlab=paste("Volume (", if (x$volume.type == "relative") {"%"} else {"cc"}, ")", sep=""), add=!new, front=front, back=back)
+}
\ No newline at end of file
