@@ -15,7 +15,13 @@ options(width=75)
 
 
 ###################################################
-### code chunk number 3: RadOnc.Rnw:85-89
+### code chunk number 3: RadOnc.Rnw:74-75
+###################################################
+news(package="RadOnc")
+
+
+###################################################
+### code chunk number 4: RadOnc.Rnw:87-91
 ###################################################
 temp <- c(readLines(paste(data.path, 'Jane_Doe.dvh', sep='/'),n=50), "...", "...")
 for (i in 1:52) {
@@ -24,58 +30,58 @@ cat(temp[i], "\n")
 
 
 ###################################################
-### code chunk number 4: RadOnc.Rnw:92-93
+### code chunk number 5: RadOnc.Rnw:94-95
 ###################################################
 johndoe <- read.DVH(file=system.file("extdata/John_Doe.dvh", package="RadOnc"), type="aria10", verbose=TRUE)
 
 
 ###################################################
-### code chunk number 5: RadOnc.Rnw:96-97 (eval = FALSE)
+### code chunk number 6: RadOnc.Rnw:98-99 (eval = FALSE)
 ###################################################
 ## read.DVH(file="Jane_Doe.dvh", type="aria10", verbose=TRUE)
 
 
 ###################################################
-### code chunk number 6: RadOnc.Rnw:99-100
+### code chunk number 7: RadOnc.Rnw:101-102
 ###################################################
 janedoe <- read.DVH(file=system.file("extdata/Jane_Doe.dvh", package="RadOnc"), type="aria10", verbose=TRUE)
 
 
 ###################################################
-### code chunk number 7: RadOnc.Rnw:103-104 (eval = FALSE)
+### code chunk number 8: RadOnc.Rnw:105-106 (eval = FALSE)
 ###################################################
 ## DVHs <- read.DVH(file=c("Jane_Doe.dvh", "John_Doe.dvh"), type="aria10")
 
 
 ###################################################
-### code chunk number 8: RadOnc.Rnw:106-108
+### code chunk number 9: RadOnc.Rnw:108-110
 ###################################################
 DVHs <- read.DVH(file=system.file(paste("extdata", c("Jane_Doe.dvh", "John_Doe.dvh"), sep="/"), package="RadOnc"), type="aria10")
 DVHs
 
 
 ###################################################
-### code chunk number 9: fig1
+### code chunk number 10: fig1
 ###################################################
 plot(as(janedoe.RTdata$structures,"DVH.list"),lwd=2.5)
 plot(janedoe[c(3,6:7)],new=FALSE,col="red",lwd=1.25)
 
 
 ###################################################
-### code chunk number 10: RadOnc.Rnw:132-134
+### code chunk number 11: RadOnc.Rnw:134-136
 ###################################################
 janedoe[1:4]
 c(janedoe["PTV"], johndoe[c("CTV", "DUODENUM")])
 
 
 ###################################################
-### code chunk number 11: RadOnc.Rnw:136-137
+### code chunk number 12: RadOnc.Rnw:138-139
 ###################################################
 temp <- janedoe
 
 
 ###################################################
-### code chunk number 12: RadOnc.Rnw:139-142
+### code chunk number 13: RadOnc.Rnw:141-144
 ###################################################
 johndoe[["CTV"]]
 janedoe[[1]] <- johndoe[["CTV"]]
@@ -83,20 +89,20 @@ janedoe[1:4]
 
 
 ###################################################
-### code chunk number 13: RadOnc.Rnw:144-145
+### code chunk number 14: RadOnc.Rnw:146-147
 ###################################################
 janedoe <- temp
 
 
 ###################################################
-### code chunk number 14: RadOnc.Rnw:149-151
+### code chunk number 15: RadOnc.Rnw:151-153
 ###################################################
 janedoe["KIDNEY$"]
 janedoe[c(2,"IGHT.*")]
 
 
 ###################################################
-### code chunk number 15: RadOnc.Rnw:156-160
+### code chunk number 16: RadOnc.Rnw:158-162
 ###################################################
 names(janedoe)[1:4] <- c("A1", "B2", "C3", "D4")
 names(rev(janedoe[1:4]))
@@ -105,20 +111,20 @@ lapply(johndoe, function(DVH) { DVH[c("DMIN", "D50%", "DMAX", "V20%")] })
 
 
 ###################################################
-### code chunk number 16: RadOnc.Rnw:162-163
+### code chunk number 17: RadOnc.Rnw:164-165
 ###################################################
 janedoe <- temp
 
 
 ###################################################
-### code chunk number 17: RadOnc.Rnw:167-169
+### code chunk number 18: RadOnc.Rnw:169-171
 ###################################################
 janedoe[1:2]$patients
 janedoe[3:4]$ID
 
 
 ###################################################
-### code chunk number 18: RadOnc.Rnw:176-180
+### code chunk number 19: RadOnc.Rnw:178-182
 ###################################################
 johndoe[["DUODENUM"]]["V20Gy"]
 johndoe[["DUODENUM"]]["D2.5%"]
@@ -127,33 +133,33 @@ johndoe[["DUODENUM"]]["D2.3286cc"]
 
 
 ###################################################
-### code chunk number 19: RadOnc.Rnw:183-185
+### code chunk number 20: RadOnc.Rnw:185-187
 ###################################################
 johndoe[["DUODENUM"]][c("V5%", "V20Gy", "D2.5%", "D2.3286cc", "Dmax")]
 johndoe[1:4]$"V20Gy,Dmax"
 
 
 ###################################################
-### code chunk number 20: RadOnc.Rnw:188-189
+### code chunk number 21: RadOnc.Rnw:190-191
 ###################################################
 johndoe[["DUODENUM"]][c("V5", "VGy", "volume", 2.5, "", "Dmax%")]
 
 
 ###################################################
-### code chunk number 21: RadOnc.Rnw:192-193
+### code chunk number 22: RadOnc.Rnw:194-195
 ###################################################
 johndoe[["LIVER"]][c("V10Gy(%)","D25%","D25%(Gy)")]
 
 
 ###################################################
-### code chunk number 22: RadOnc.Rnw:196-198
+### code chunk number 23: RadOnc.Rnw:198-200
 ###################################################
 johndoe[["LIVER"]][c("Dintegral","Dintegral(>0cGy)")]
 johndoe[["LIVER"]][c("Dintegral(<20Gy)","Dintegral(10-20Gy)")]
 
 
 ###################################################
-### code chunk number 23: RadOnc.Rnw:206-210
+### code chunk number 24: RadOnc.Rnw:208-212
 ###################################################
 gEUD(janedoe[1:3], 6:8)
 gEUD(janedoe[1:3], 1) == unlist(janedoe[1:3]$"Dmean")
@@ -162,26 +168,27 @@ gEUD(janedoe[1:3], -Inf) == unlist(janedoe[1:3]$"Dmin")
 
 
 ###################################################
-### code chunk number 24: RadOnc.Rnw:217-218
+### code chunk number 25: RadOnc.Rnw:219-221
 ###################################################
-LQE(c(4500, 5500, 6000), aB=3, fractions=c(20, 30))
+LQE(c(4500, 5500, 6000), aB=3, fractions=c(300, 200))
+LQE(c(4500, 5500, 6000), aB=3, N=c(20, 36))
 
 
 ###################################################
-### code chunk number 25: fig2
+### code chunk number 26: fig2
 ###################################################
 plot(janedoe[[3]], volume="relative", dose="absolute", type="cumulative")
 
 
 ###################################################
-### code chunk number 26: fig3
+### code chunk number 27: fig3
 ###################################################
 plot(janedoe[1:3], plot.type="i", col=c("red", "green", "blue"), 
 legend="topright", legend.labels=names(janedoe[1:3]))
 
 
 ###################################################
-### code chunk number 27: fig4
+### code chunk number 28: fig4
 ###################################################
 plot(c(johndoe["STOMACH"],janedoe["STOMACH"]), #group 1
 c(janedoe["LIVER"],johndoe["LIVER"]), #group 2
@@ -191,7 +198,7 @@ lwd=2, lty="dashed", fill.lty="solid", fill.transparency=0.3)
 
 
 ###################################################
-### code chunk number 28: fig5
+### code chunk number 29: fig5
 ###################################################
 group1 <- c("CTV", "PTV")
 group2 <- c("LIVER", "STOMACH", "SMALL_BOWEL")
@@ -202,13 +209,26 @@ col=c("red", "blue"), lty="dashed", fill.lty="solid")
 
 
 ###################################################
-### code chunk number 29: fig6
+### code chunk number 30: fig6
 ###################################################
 plot(janedoe[2:9], plot.type="b", volume="abs", dose="rel")
 
 
 ###################################################
-### code chunk number 30: fig7
+### code chunk number 31: RadOnc.Rnw:296-297 (eval = FALSE)
+###################################################
+## plot(stomach, col="lightblue")
+
+
+###################################################
+### code chunk number 32: fig7
+###################################################
+par(mar=c(2,2,2,2))
+persp(stomach$doses,as.numeric(colnames(stomach$volumes)),stomach$volumes,border=NA,col="lightblue",shade=0.65,xlab="Dose (Gy)",zlab="Volume (cc)",ylab="z (mm)",ticktype="detailed",phi=30, theta=30)
+
+
+###################################################
+### code chunk number 33: fig8
 ###################################################
 plot(janedoe)
 plot(median(janedoe), new=FALSE, col="red", lwd=2)
@@ -216,7 +236,7 @@ plot(mean(janedoe), new=FALSE, col="blue", lwd=2, lty="dashed")
 
 
 ###################################################
-### code chunk number 31: RadOnc.Rnw:309-312
+### code chunk number 34: RadOnc.Rnw:327-330
 ###################################################
 L.kidney <- janedoe[["LEFT_KIDNEY"]]
 R.kidney <- janedoe[["RIGHT_KIDNEY"]]
@@ -224,7 +244,7 @@ total.kidney <- sum(janedoe[c("LEFT_KIDNEY", "RIGHT_KIDNEY")])
 
 
 ###################################################
-### code chunk number 32: RadOnc.Rnw:314-320 (eval = FALSE)
+### code chunk number 35: RadOnc.Rnw:332-338 (eval = FALSE)
 ###################################################
 ## L.kidney <- janedoe[["LEFT_KIDNEY"]]
 ## R.kidney <- janedoe[["RIGHT_KIDNEY"]]
@@ -235,7 +255,7 @@ total.kidney <- sum(janedoe[c("LEFT_KIDNEY", "RIGHT_KIDNEY")])
 
 
 ###################################################
-### code chunk number 33: fig8
+### code chunk number 36: fig9
 ###################################################
 plot(total.kidney, type="diff", volume="abs")
 plot(L.kidney, new=FALSE, type="diff", volume="abs", col="red")
@@ -243,7 +263,7 @@ plot(R.kidney, new=FALSE, type="diff", volume="abs", col="blue")
 
 
 ###################################################
-### code chunk number 34: RadOnc.Rnw:336-339
+### code chunk number 37: RadOnc.Rnw:354-357
 ###################################################
 groupA <- janedoe[c("LIVER","LEFT_KIDNEY","RIGHT_KIDNEY","CORD")]
 groupB <- janedoe[c("CTV", "PTV")]
@@ -251,14 +271,14 @@ t.test(unlist(groupA$"V20Gy"), unlist(groupB$"V20Gy"))
 
 
 ###################################################
-### code chunk number 35: RadOnc.Rnw:344-346 (eval = FALSE)
+### code chunk number 38: RadOnc.Rnw:362-364 (eval = FALSE)
 ###################################################
 ## AvB <- t.test(groupA, groupB)
 ## plot(AvB$dose, AvB$p, type="l", log="y", xlab="Dose (cGy)", ylab="p-value")
 
 
 ###################################################
-### code chunk number 36: fig9
+### code chunk number 39: fig10
 ###################################################
 AvB <- t.test(groupA, groupB)
 plot(AvB$dose, AvB$p, type="l", log="y", xlab="Dose (cGy)", ylab="p-value")
@@ -268,32 +288,32 @@ text(2000,approx(AvB$dose, AvB$p, 2000)$y, col="red", labels="V20Gy (p=5.347e-05
 
 
 ###################################################
-### code chunk number 37: RadOnc.Rnw:371-372 (eval = FALSE)
+### code chunk number 40: RadOnc.Rnw:389-390 (eval = FALSE)
 ###################################################
 ## data <- read.DICOM.RT(path="<<DICOM directory>>", verbose=TRUE)
 
 
 ###################################################
-### code chunk number 38: RadOnc.Rnw:376-377
+### code chunk number 41: RadOnc.Rnw:394-395
 ###################################################
 data("RadOnc")
 
 
 ###################################################
-### code chunk number 39: RadOnc.Rnw:384-386
+### code chunk number 42: RadOnc.Rnw:402-404
 ###################################################
 teeth[1:2]
 c(cord, mandible)
 
 
 ###################################################
-### code chunk number 40: RadOnc.Rnw:388-389
+### code chunk number 43: RadOnc.Rnw:406-407
 ###################################################
 temp <- teeth
 
 
 ###################################################
-### code chunk number 41: RadOnc.Rnw:391-394
+### code chunk number 44: RadOnc.Rnw:409-412
 ###################################################
 teeth[[1]]
 teeth[[1]] <- teeth[["Tooth #3"]]
@@ -301,19 +321,19 @@ teeth
 
 
 ###################################################
-### code chunk number 42: RadOnc.Rnw:396-397
+### code chunk number 45: RadOnc.Rnw:414-415
 ###################################################
 teeth <- temp
 
 
 ###################################################
-### code chunk number 43: RadOnc.Rnw:401-402
+### code chunk number 46: RadOnc.Rnw:419-420
 ###################################################
 teeth["Tooth.*"]
 
 
 ###################################################
-### code chunk number 44: RadOnc.Rnw:407-411
+### code chunk number 47: RadOnc.Rnw:425-429
 ###################################################
 names(teeth) <- c("Larry", "Curly", "Moe")
 names(rev(teeth[1:3]))
@@ -322,55 +342,61 @@ lapply(teeth, function(tooth) { range(tooth) })
 
 
 ###################################################
-### code chunk number 45: RadOnc.Rnw:413-414
+### code chunk number 48: RadOnc.Rnw:431-432
 ###################################################
 teeth <- temp
 
 
 ###################################################
-### code chunk number 46: fig10 (eval = FALSE)
+### code chunk number 49: fig11 (eval = FALSE)
 ###################################################
 ## plot(mandible)
 
 
 ###################################################
-### code chunk number 47: fig11 (eval = FALSE)
+### code chunk number 50: fig12 (eval = FALSE)
 ###################################################
 ## plot(cord)
 
 
 ###################################################
-### code chunk number 48: RadOnc.Rnw:452-453 (eval = FALSE)
+### code chunk number 51: RadOnc.Rnw:470-471 (eval = FALSE)
 ###################################################
 ## compareStructures(teeth, method="axial", plot=TRUE)
 
 
 ###################################################
-### code chunk number 49: fig12
+### code chunk number 52: fig13
 ###################################################
 compareStructures(teeth, method="axial", plot=TRUE, pixels=40)
 
 
 ###################################################
-### code chunk number 50: RadOnc.Rnw:465-466
+### code chunk number 53: RadOnc.Rnw:483-484
 ###################################################
 teeth <- teeth[c(1,3)]
 
 
 ###################################################
-### code chunk number 51: RadOnc.Rnw:468-469
+### code chunk number 54: RadOnc.Rnw:486-487
 ###################################################
 compareStructures(teeth, method="hausdorff", hausdorff.method="mean")
 
 
 ###################################################
-### code chunk number 52: RadOnc.Rnw:471-472
+### code chunk number 55: RadOnc.Rnw:489-490
 ###################################################
 teeth <- temp
 
 
 ###################################################
-### code chunk number 53: RadOnc.Rnw:499-500
+### code chunk number 56: RadOnc.Rnw:494-495
+###################################################
+compareStructures(teeth, method="DSC")
+
+
+###################################################
+### code chunk number 57: RadOnc.Rnw:523-524
 ###################################################
 news(package="RadOnc")
 
